@@ -1,5 +1,7 @@
 context("linestring")
 
+invisible(linting_opts(suppress_pkgcheck_warnings = TRUE))
+
 stt <- '{ "type": "LineString", "coordinates": [ [100.0, 0.0], [101.0, 1.0] ] }'
 aa <- linestring(stt)
 
@@ -16,11 +18,9 @@ test_that("methods on linestrings work", {
   expect_equal(geo_bbox(aa), c(100, 0, 101, 1))
   expect_equal(geo_type(aa), "LineString")
 
-  geo_write(aa, f <- tempfile())
-  expect_is(f, "character")
-
-  # cleanup
-  unlink(f)
+  f <- file(tempfile())
+  geo_write(aa, f)
+  expect_is(f, "file")
 })
 
 test_that("print method for multipolygon", {
@@ -50,6 +50,8 @@ test_that("linestring fails well", {
 test_that("linestring fails well with geojson linting on", {
   invisible(linting_opts(TRUE, method = "hint", error = TRUE))
 
+  skip_if_not_installed("geojsonlint")
+
   expect_error(linestring('{"type": "LineString", "coordinates": []}'),
             "a line needs to have two or more coordinates to be valid")
 
