@@ -1,5 +1,7 @@
 context("multilinestring")
 
+invisible(linting_opts(suppress_pkgcheck_warnings = TRUE))
+
 stt <- '{ "type": "MultiLineString",
     "coordinates": [ [ [100.0, 0.0], [101.0, 1.0] ], [ [102.0, 2.0], [103.0, 3.0] ] ] }'
 aa <- multilinestring(stt)
@@ -23,11 +25,9 @@ test_that("methods on multilinestrings work", {
   expect_equal(geo_bbox(aa), c(100, 0, 101, 1))
   expect_equal(geo_type(aa), "MultiLineString")
 
-  geo_write(aa, f <- tempfile())
-  expect_is(f, "character")
-
-  # cleanup
-  unlink(f)
+  f <- file(tempfile())
+  geo_write(aa, f)
+  expect_is(f, "file")
 })
 
 test_that("print method for multilinestring", {
@@ -65,6 +65,8 @@ test_that("multilinestring fails well", {
 test_that("multilinestring fails well with geojson linting on", {
   invisible(linting_opts(TRUE, method = "hint", error = TRUE))
 
+  skip_if_not_installed("geojsonlint")
+
   expect_error(multilinestring('{"type": "MultiLineString", "coordinates": [[]]}'),
                "a line needs to have two or more coordinates to be valid")
 })
