@@ -1,5 +1,7 @@
 context("multipoint")
 
+invisible(linting_opts(suppress_pkgcheck_warnings = TRUE))
+
 # spaces
 stt <- '{"type":"MultiPoint","coordinates":[[100.0,0.0],[101.0,1.0]]}'
 aa <- multipoint(stt)
@@ -26,11 +28,9 @@ test_that("methods on multipoints work", {
   expect_equal(geo_bbox(aa), c(100, 0, 101, 1))
   expect_equal(geo_type(aa), "MultiPoint")
 
-  geo_write(aa, f <- tempfile())
-  expect_is(f, "character")
-
-  # cleanup
-  unlink(f)
+  f <- file(tempfile())
+  geo_write(aa, f)
+  expect_is(f, "file")
 })
 
 test_that("print method for multipoint", {
@@ -57,6 +57,8 @@ test_that("multipoint fails well", {
 test_that("multipoint fails well with geojson linting on", {
   invisible(linting_opts(TRUE, method = "hint", error = TRUE))
 
+  skip_if_not_installed("geojsonlint")
+
   expect_error(multipoint('{"type": "MultiPoint", "coordinates": [1]}'),
                "position should be an array, is a number instead")
 
